::: py_ballisticcalc.engines.base_engine.BaseIntegrationEngine

::: py_ballisticcalc.engines.base_engine.BaseEngineConfigDict

::: py_ballisticcalc.engines.RK4IntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc.engines.EulerIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc.engines.VelocityVerletIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc.engines.SciPyIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedBaseIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedRK4IntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedEulerIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list